J2kDecoder

Struct J2kDecoder 

pub struct J2kDecoder<'a> { /* private fields */ }
JPEG 2000 decoder that can return host or Metal-resident surfaces.

Implementations

Source

impl<'a> J2kDecoder<'a>

pub fn new(input: &'a [u8]) -> Result<Self, Error>

Parse a J2K or HTJ2K codestream into a decoder.

pub fn from_view(view: J2kView<'a>) -> Result<Self, Error>

Create a decoder from an already parsed J2K view.

pub fn inner(&self) -> &CpuDecoder<'a>

Borrow the underlying CPU J2K decoder.

pub fn decode_to_device_with_session( &mut self, fmt: PixelFormat, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a full image into a Metal-resident device surface.

pub fn decode_to_host_surface( &mut self, fmt: PixelFormat, ) -> Result<Surface, Error>

Decode a full image into a host-backed surface.

pub fn decode_region_to_host_surface( &mut self, fmt: PixelFormat, roi: Rect, ) -> Result<Surface, Error>

Decode a source region into a host-backed surface.

pub fn decode_scaled_to_host_surface( &mut self, fmt: PixelFormat, scale: Downscale, ) -> Result<Surface, Error>

Decode a full image at reduced resolution into a host-backed surface.

pub fn decode_region_scaled_to_host_surface( &mut self, fmt: PixelFormat, roi: Rect, scale: Downscale, ) -> Result<Surface, Error>

Decode a source region at reduced resolution into a host-backed surface.

pub fn decode_to_cpu_staged_metal_surface_with_session( &mut self, fmt: PixelFormat, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a full image on CPU and upload the result into a Metal surface.

pub fn decode_region_to_cpu_staged_metal_surface_with_session( &mut self, fmt: PixelFormat, roi: Rect, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a source region on CPU and upload the result into a Metal surface.

pub fn decode_scaled_to_cpu_staged_metal_surface_with_session( &mut self, fmt: PixelFormat, scale: Downscale, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a full image at reduced resolution on CPU and upload it into Metal.

pub fn decode_region_scaled_to_cpu_staged_metal_surface_with_session( &mut self, fmt: PixelFormat, roi: Rect, scale: Downscale, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a scaled source region on CPU and upload it into a Metal surface.

pub fn decode_region_to_device_with_session( &mut self, fmt: PixelFormat, roi: Rect, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a source region into a Metal-resident device surface.

pub fn decode_scaled_to_device_with_session( &mut self, fmt: PixelFormat, scale: Downscale, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a full image at reduced resolution into a Metal-resident surface.

pub fn decode_region_scaled_to_device_with_session( &mut self, fmt: PixelFormat, roi: Rect, scale: Downscale, session: &MetalBackendSession, ) -> Result<Surface, Error>

Decode a scaled source region into a Metal-resident device surface.