MetalEncodeStageAccelerator

Struct MetalEncodeStageAccelerator 

pub struct MetalEncodeStageAccelerator { /* private fields */ }
Encode-stage accelerator for JPEG 2000 Metal work.

The type is wired into the public J2K encode-stage interface and reports dispatches for each required encode stage.

Implementations

Source

impl MetalEncodeStageAccelerator

pub fn with_cpu_forward_rct() -> Self

Create an accelerator that leaves forward RCT on the CPU path.

pub fn for_auto_host_output() -> Self

Create the conservative automatic accelerator for host codestream output.

pub fn for_ht_code_block_encode() -> Self

Create an accelerator that only attempts the HT code-block stage on Metal.

pub fn deinterleave_attempts(&self) -> usize

Number of deinterleave stage attempts.

pub fn forward_rct_attempts(&self) -> usize

Number of forward RCT stage attempts.

pub fn forward_ict_attempts(&self) -> usize

Number of forward ICT stage attempts.

pub fn forward_dwt53_attempts(&self) -> usize

Number of forward 5/3 DWT stage attempts.

pub fn forward_dwt97_attempts(&self) -> usize

Number of forward 9/7 DWT stage attempts.

pub fn quantize_subband_attempts(&self) -> usize

Number of sub-band quantization stage attempts.

pub fn tier1_code_block_attempts(&self) -> usize

Number of classic Tier-1 code-block encode attempts.

pub fn ht_code_block_attempts(&self) -> usize

Number of HT code-block encode attempts.

pub fn packetization_attempts(&self) -> usize

Number of packetization stage attempts.

pub fn deinterleave_dispatches(&self) -> usize

Number of deinterleave Metal dispatches.

pub fn forward_rct_dispatches(&self) -> usize

Number of forward RCT Metal dispatches.

pub fn forward_ict_dispatches(&self) -> usize

Number of forward ICT Metal dispatches.

pub fn forward_dwt53_dispatches(&self) -> usize

Number of forward 5/3 DWT Metal dispatches.

pub fn forward_dwt97_dispatches(&self) -> usize

Number of forward 9/7 DWT Metal dispatches.

pub fn quantize_subband_dispatches(&self) -> usize

Number of sub-band quantization Metal dispatches.

pub fn tier1_code_block_dispatches(&self) -> usize

Number of classic Tier-1 Metal dispatches.

pub fn ht_code_block_dispatches(&self) -> usize

Number of HT code-block Metal dispatches.

pub fn packetization_dispatches(&self) -> usize

Number of packetization Metal dispatches.