pub struct MetalEncodeStageAccelerator { /* private fields */ }Expand description
Encode-stage accelerator for JPEG 2000 Metal work.
The type is wired into the public J2K encode-stage interface and reports dispatches for each required encode stage.
Implementations
Sourceimpl MetalEncodeStageAccelerator
impl MetalEncodeStageAccelerator
Sourcepub fn with_cpu_forward_rct() -> Self
pub fn with_cpu_forward_rct() -> Self
Create an accelerator that leaves forward RCT on the CPU path.
Sourcepub fn for_auto_host_output() -> Self
pub fn for_auto_host_output() -> Self
Create the conservative automatic accelerator for host codestream output.
Sourcepub fn for_ht_code_block_encode() -> Self
pub fn for_ht_code_block_encode() -> Self
Create an accelerator that only attempts the HT code-block stage on Metal.
Sourcepub fn deinterleave_attempts(&self) -> usize
pub fn deinterleave_attempts(&self) -> usize
Number of deinterleave stage attempts.
Sourcepub fn forward_rct_attempts(&self) -> usize
pub fn forward_rct_attempts(&self) -> usize
Number of forward RCT stage attempts.
Sourcepub fn forward_ict_attempts(&self) -> usize
pub fn forward_ict_attempts(&self) -> usize
Number of forward ICT stage attempts.
Sourcepub fn forward_dwt53_attempts(&self) -> usize
pub fn forward_dwt53_attempts(&self) -> usize
Number of forward 5/3 DWT stage attempts.
Sourcepub fn forward_dwt97_attempts(&self) -> usize
pub fn forward_dwt97_attempts(&self) -> usize
Number of forward 9/7 DWT stage attempts.
Sourcepub fn quantize_subband_attempts(&self) -> usize
pub fn quantize_subband_attempts(&self) -> usize
Number of sub-band quantization stage attempts.
Sourcepub fn tier1_code_block_attempts(&self) -> usize
pub fn tier1_code_block_attempts(&self) -> usize
Number of classic Tier-1 code-block encode attempts.
Sourcepub fn ht_code_block_attempts(&self) -> usize
pub fn ht_code_block_attempts(&self) -> usize
Number of HT code-block encode attempts.
Sourcepub fn packetization_attempts(&self) -> usize
pub fn packetization_attempts(&self) -> usize
Number of packetization stage attempts.
Sourcepub fn deinterleave_dispatches(&self) -> usize
pub fn deinterleave_dispatches(&self) -> usize
Number of deinterleave Metal dispatches.
Sourcepub fn forward_rct_dispatches(&self) -> usize
pub fn forward_rct_dispatches(&self) -> usize
Number of forward RCT Metal dispatches.
Sourcepub fn forward_ict_dispatches(&self) -> usize
pub fn forward_ict_dispatches(&self) -> usize
Number of forward ICT Metal dispatches.
Sourcepub fn forward_dwt53_dispatches(&self) -> usize
pub fn forward_dwt53_dispatches(&self) -> usize
Number of forward 5/3 DWT Metal dispatches.
Sourcepub fn forward_dwt97_dispatches(&self) -> usize
pub fn forward_dwt97_dispatches(&self) -> usize
Number of forward 9/7 DWT Metal dispatches.
Sourcepub fn quantize_subband_dispatches(&self) -> usize
pub fn quantize_subband_dispatches(&self) -> usize
Number of sub-band quantization Metal dispatches.
Sourcepub fn tier1_code_block_dispatches(&self) -> usize
pub fn tier1_code_block_dispatches(&self) -> usize
Number of classic Tier-1 Metal dispatches.
Sourcepub fn ht_code_block_dispatches(&self) -> usize
pub fn ht_code_block_dispatches(&self) -> usize
Number of HT code-block Metal dispatches.
Sourcepub fn packetization_dispatches(&self) -> usize
pub fn packetization_dispatches(&self) -> usize
Number of packetization Metal dispatches.